@@ -16,6 +16,7 @@ from suite_py.commands import create_qa
 from suite_py.commands import delete_qa
 from suite_py.commands import status
 from suite_py.commands import check
+from suite_py.commands import ip
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.config import Config
 from suite_py.__version__ import __version__
@@ -139,3 +140,12 @@ def cli_status(ctx):
 @click.pass_context
 def cli_check(ctx):
     check.entrypoint(ctx.obj["captainhook_timeout"])
+
+
+@main.command(
+    "ip", help="Ottieni gli indirizzi IP degli hosts dove il task è running",
+)
+@click.argument("environment", type=click.Choice(("staging", "production")))
+@click.pass_context
+def cli_ip(ctx, environment):
+    ip.entrypoint(ctx.obj["project"], environment)
