@@ -47,7 +47,9 @@ def ask_card():
 def checkout_branch(project, issue):
     branch_name = prompt_utils.ask_questions_input(
         "Inserisci nome del branch: ",
-        re.sub(r'([\s\\.,~\^:\[\]"\'?]|[^\x00-\x7F])+', "-", issue["summary"]).lower(),
+        re.sub(
+            r'([\s\\.,~\^:\(\)\[\]\<\>"\'?]|[^\x00-\x7F])+', "-", issue["summary"]
+        ).lower(),
     )
 
     parent_branch_name = prompt_utils.ask_questions_input(
