@@ -85,8 +85,12 @@ def create_pr(repo, branch_name, id_card=None):
 
     body = f"{link} \n\n {pr_body}"
 
+    is_draft = prompt_utils.ask_confirm(
+        "Vuoi aprire la pull request come draft?", default=False
+    )
+
     try:
-        pr = github.create_pr(repo, branch_name, title, body, base_branch)
+        pr = github.create_pr(repo, branch_name, title, body, base_branch, is_draft)
         logger.info(f"Pull request numero {pr.number} creata! {pr.html_url}")
     except GithubException as e:
         logger.error("Errore durante la richiesta a GitHub: ")
